@@ -1227,7 +1227,7 @@ def validity_check(df, Timed=True):
 
         elif (row_bounds == row_bounds):
             num = 120
-            validity_report[col_name] = pd.to_numeric(df[col_name]) < num
+            validity_report[col_name] = pd.to_numeric(df[col_name],errors='coerce') < num
 
         elif (row_format == row_format):
             search = row_format
